import React from 'react';
import PropTypes from 'prop-types';

/**
 * core component
 */
export default class EChartsOfReact extends React.Component {
  static propTypes = {
    /**
     * echarts object
     */
    echarts: PropTypes.object,

    /**
     * id selector
     */
    id: PropTypes.string.isRequired,

    /**
     * echarts option
     */
    option: PropTypes.object,

    /**
     * default width
     */
    defaultWidth: PropTypes.oneOfType([PropTypes.number, PropTypes.string])
      .isRequired,

    /**
     * default height
     */
    defaultHeight: PropTypes.oneOfType([PropTypes.number, PropTypes.string])
      .isRequired,

    /**
     * 是否不跟之前设置的 option 进行合并
     * 可选：true | false
     * 默认： false，即合并
     * 注：当为 false 时，数据又多变为少时，图表不会发生改变（因为数据合并）；此时若需要图表发生变化，则设置为 true：不合并 option
     */
    notMerge: PropTypes.bool
  };

  componentDidMount() {
    const { id, option, echarts, notMerge } = this.props;
    this.chart = echarts.init(document.getElementById(id));
    if (!!option) {
      this.chart.setOption(option, notMerge);
    }
    window.addEventListener('resize', this.chartSizeChange);
  }

  componentWillReceiveProps(nextProps) {
    if (this.props.option !== nextProps.option) {
      this.chart.setOption(nextProps.option, nextProps.notMerge);
    }
  }

  componentWillUnmount() {
    window.removeEventListener('resize', this.chartSizeChange);
  }

  chartSizeChange = () => {
    this.chart.resize();
  };

  render() {
    const { id, defaultWidth, defaultHeight } = this.props;
    return (
      <div id={id} style={{ width: defaultWidth, height: defaultHeight }} />
    );
  }
}
